@@ -47,25 +47,25 @@ static guint32 display_serial = 1;
 
 struct GdmDisplayPrivate
 {
-        char            *id;
-        char            *seat_id;
+        char                 *id;
+        char                 *seat_id;
 
-        char            *remote_hostname;
-        int              x11_display_number;
-        char            *x11_display_name;
-        int              status;
-        time_t           creation_time;
-        char            *slave_command;
+        char                 *remote_hostname;
+        int                   x11_display_number;
+        char                 *x11_display_name;
+        int                   status;
+        time_t                creation_time;
+        char                 *slave_command;
 
         char                 *x11_cookie;
         gsize                 x11_cookie_size;
         GdmDisplayAccessFile *access_file;
 
-        gboolean         is_local;
-        guint            finish_idle_id;
+        gboolean              is_local;
+        guint                 finish_idle_id;
 
-        GdmSlaveProxy   *slave_proxy;
-        DBusGConnection *connection;
+        GdmSlaveProxy        *slave_proxy;
+        DBusGConnection      *connection;
         GdmDisplayAccessFile *user_access_file;
 };
 
@@ -204,13 +204,16 @@ gdm_display_real_add_user_authorization (GdmDisplay *display,
                                          GError    **error)
 {
         GdmDisplayAccessFile *access_file;
-        GError *access_file_error;
+        GError               *access_file_error;
 
         g_return_val_if_fail (GDM_IS_DISPLAY (display), FALSE);
         g_return_val_if_fail (display->priv->access_file != NULL, FALSE);
 
+        g_debug ("GdmDisplay: Adding user authorization for %s", username);
+
         access_file_error = NULL;
-        access_file = _create_access_file_for_user (display, username,
+        access_file = _create_access_file_for_user (display,
+                                                    username,
                                                     &access_file_error);
 
         if (access_file == NULL) {
@@ -219,9 +222,13 @@ gdm_display_real_add_user_authorization (GdmDisplay *display,
         }
 
         if (!gdm_display_access_file_add_display_with_cookie (access_file,
-                                                              display, display->priv->x11_cookie,
+                                                              display,
+                                                              display->priv->x11_cookie,
                                                               display->priv->x11_cookie_size,
                                                               &access_file_error)) {
+                g_debug ("GdmDisplay: Unable to add user authorization for %s: %s",
+                         username,
+                         access_file_error->message);
                 g_propagate_error (error, access_file_error);
                 gdm_display_access_file_close (access_file);
                 g_object_unref (access_file);
@@ -231,6 +238,8 @@ gdm_display_real_add_user_authorization (GdmDisplay *display,
         *filename = gdm_display_access_file_get_path (access_file);
         display->priv->user_access_file = access_file;
 
+        g_debug ("GdmDisplay: Added user authorization for %s: %s", username, *filename);
+
         return TRUE;
 }
 
@@ -253,6 +262,33 @@ gdm_display_add_user_authorization (GdmDisplay *display,
         return ret;
 }
 
+static gboolean
+gdm_display_real_set_slave_bus_name (GdmDisplay *display,
+                                     const char *name,
+                                     GError    **error)
+{
+
+        return TRUE;
+}
+
+gboolean
+gdm_display_set_slave_bus_name (GdmDisplay *display,
+                                const char *name,
+                                GError    **error)
+{
+        gboolean ret;
+
+        g_return_val_if_fail (GDM_IS_DISPLAY (display), FALSE);
+
+        g_debug ("Setting slave bus name:%s on display %s", name, display->priv->x11_display_name);
+
+        g_object_ref (display);
+        ret = GDM_DISPLAY_GET_CLASS (display)->set_slave_bus_name (display, name, error);
+        g_object_unref (display);
+
+        return ret;
+}
+
 static gboolean
 gdm_display_real_remove_user_authorization (GdmDisplay *display,
                                             const char *username,
@@ -346,6 +382,20 @@ gdm_display_get_x11_display_number (GdmDisplay *display,
        return TRUE;
 }
 
+gboolean
+gdm_display_get_seat_id (GdmDisplay *display,
+                         char      **seat_id,
+                         GError    **error)
+{
+       g_return_val_if_fail (GDM_IS_DISPLAY (display), FALSE);
+
+       if (seat_id != NULL) {
+               *seat_id = g_strdup (display->priv->seat_id);
+       }
+
+       return TRUE;
+}
+
 static gboolean
 finish_idle (GdmDisplay *display)
 {
@@ -468,7 +518,7 @@ gdm_display_real_unmanage (GdmDisplay *display)
 
         display->priv->status = GDM_DISPLAY_UNMANAGED;
 
-        g_debug ("GdmDisplay unmanage display");
+        g_debug ("GdmDisplay: unmanage display");
 
         if (display->priv->slave_proxy != NULL) {
                 gdm_slave_proxy_stop (display->priv->slave_proxy);
@@ -499,7 +549,7 @@ gdm_display_unmanage (GdmDisplay *display)
 
         g_return_val_if_fail (GDM_IS_DISPLAY (display), FALSE);
 
-        g_debug ("Unmanaging display");
+        g_debug ("GdmDisplay: Unmanaging display");
 
         g_object_ref (display);
         ret = GDM_DISPLAY_GET_CLASS (display)->unmanage (display);
@@ -759,7 +809,7 @@ gdm_display_dispose (GObject *object)
                 display->priv->finish_idle_id = 0;
         }
 
-        g_debug ("Disposing display");
+        g_debug ("GdmDisplay: Disposing display");
         gdm_display_unmanage (display);
 
         G_OBJECT_CLASS (gdm_display_parent_class)->dispose (object);
@@ -779,6 +829,7 @@ gdm_display_class_init (GdmDisplayClass *klass)
         klass->create_authority = gdm_display_real_create_authority;
         klass->add_user_authorization = gdm_display_real_add_user_authorization;
         klass->remove_user_authorization = gdm_display_real_remove_user_authorization;
+        klass->set_slave_bus_name = gdm_display_real_set_slave_bus_name;
         klass->manage = gdm_display_real_manage;
         klass->finish = gdm_display_real_finish;
         klass->unmanage = gdm_display_real_unmanage;
@@ -790,13 +841,6 @@ gdm_display_class_init (GdmDisplayClass *klass)
                                                               "id",
                                                               NULL,
                                                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
-        g_object_class_install_property (object_class,
-                                         PROP_SEAT_ID,
-                                         g_param_spec_string ("seat-id",
-                                                              "seat id",
-                                                              "seat id",
-                                                              NULL,
-                                                              G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
         g_object_class_install_property (object_class,
                                          PROP_REMOTE_HOSTNAME,
                                          g_param_spec_string ("remote-hostname",
@@ -820,6 +864,13 @@ gdm_display_class_init (GdmDisplayClass *klass)
                                                               "x11-display-name",
                                                               NULL,
                                                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+        g_object_class_install_property (object_class,
+                                         PROP_SEAT_ID,
+                                         g_param_spec_string ("seat-id",
+                                                              "seat id",
+                                                              "seat id",
+                                                              NULL,
+                                                              G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
         g_object_class_install_property (object_class,
                                          PROP_X11_COOKIE,
                                          g_param_spec_string ("x11-cookie",
@@ -878,7 +929,7 @@ gdm_display_finalize (GObject *object)
 
         g_return_if_fail (display->priv != NULL);
 
-        g_debug ("Finalizing display: %s", display->priv->id);
+        g_debug ("GdmDisplay: Finalizing display: %s", display->priv->id);
         g_free (display->priv->id);
         g_free (display->priv->seat_id);
         g_free (display->priv->remote_hostname);
